@@ -19,7 +19,7 @@ use Test2::API 1.302200 qw( context );
 
 our @EXPORT_OK = qw( all_perl_files_scripts_ok file_scripts_ok );
 
-our $VERSION = 'v0.2.1';
+our $VERSION = 'v0.2.2';
 
 
 sub file_scripts_ok {
@@ -185,7 +185,7 @@ Test::MixedScripts - test text for mixed and potentially confusable Unicode scri
 
 =head1 VERSION
 
-version v0.2.1
+version v0.2.2
 
 =head1 SYNOPSIS
 
@@ -200,7 +200,7 @@ version v0.2.1
 This is a module to test that Perl code and other text files do not have potentially malicious or confusing Unicode
 combinations.
 
-For example, the text for the domain names "оnе.example.com" and "one.example.com" look indistinguishable in many fonts,
+For example, the text for the domain names "E<0x043e>nE<0x0435>.example.com" and "one.example.com" look indistinguishable in many fonts,
 but the first one has Cyrillic letters.  If your software interactied with a service on the second domain, then someone
 can operate a service on the first domain and attempt to fool developers into using their domain instead.
 
@@ -241,6 +241,9 @@ This applies L</file_scripts_ok> to all of the Perl scripts in C<@dirs>, or the
 
 The current version does not support specifying exceptions to specific lines of POD.
 
+The only workaround for this is to escape the individual characters using the C<E> formatting code. See L<perlpod>
+for more information. See L<perlpod> for more details.
+
 =head1 SEE ALSO
 
 L<Test::PureASCII> tests that only ASCII characters are used.
